==> ugrp-0.2.1.gem: spec/dummy/db/seed/once/development/0520_ugrp_users.rb <==
# frozen_string_literal: true

# The actual administrator
u = Ugrp::User.new(
  username: 'administrator',
  name: 'Administrator',
  email: 'administrator@example.com',
  password: 'administrator',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
u.roles << Ugrp::Role.find_by_name('r_super_user')
u.save!

# Everard
u = Ugrp::User.new(
  username: 'everard',
  name: 'Everard Brown',
  email: 'everard.brown@htcl.eu',
  password: '3v3rard@dev',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
u.roles << Ugrp::Role.find_by(name: 'r_developer')
# u.roles << Ugrp::Role.find_by(name: 'trainer', domain: Ugrp::Domain.default_domain)
u.save!

# file = File.new(File.expand_path('images/em.png', __FILE__), binmode: true, encoding: "ASCII-8BIT")
# data = file.read
# photo = AssetManagement::AssetData.create(
#   filename: File.basename(file.path),
#   data: data,
#   size: data.size,
#   mime_type: 'image/jpeg',
#   folder: AssetManagement::VirtualFolder.find_by_name('images')
# )

#
# Generate development/test user accounts ------------------------------------------
#

# The domain_administrator
u = Ugrp::User.new(
  username: 'domain_administrator',
  name: 'Domain Admin',
  email: 'domain_administrator@example.com',
  password: 'domain_administrator',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('domain_administrator')
u.save!

# The manager
u = Ugrp::User.new(
  username: 'manager',
  name: 'Manager',
  email: 'manager@example.com',
  password: 'manager',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

# The staff
u = Ugrp::User.new(
  username: 'staff',
  name: 'Staff',
  email: 'staff@example.com',
  password: 'staff',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

# restricted staff member
u = Ugrp::User.new(
  username: 'restricted_staff',
  name: 'Restricted staff',
  email: 'restricted_staff@example.com',
  password: 'restricted_staff',
  confirmed_at: Time.now
)
u.save!

# The trainer
u = Ugrp::User.new(
  username: 'trainer',
  name: 'Trainer',
  email: 'trainer@example.com',
  password: 'trainer',
  confirmed_at: Time.now
)
# u.domains << Ugrp::Domain.find_by_url('planit.co.uk')
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

# The attendee
u = Ugrp::User.new(
  username: 'attendee',
  name: 'Attendee',
  email: 'attendee@example.com',
  password: 'attendee',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

#
# Generate some other arbitrary users -----------------------------------------
#

# Managers
u = Ugrp::User.new(
  username: 'manager1',
  name: 'Manager-1',
  email: 'manager1@example.com',
  password: 'manager1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

u = Ugrp::User.new(
  username: 'manager2',
  name: 'Manager-2',
  email: 'manager2@example.com',
  password: 'manager2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

# Staff
u = Ugrp::User.new(
  username: 'staff1',
  name: 'Staff-1',
  email: 'staff1@example.com',
  password: 'staff1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

u = Ugrp::User.new(
  username: 'staff2',
  name: 'Staff-2',
  email: 'staff2@example.com',
  password: 'staff2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

# Trainers
u = Ugrp::User.new(
  username: 'trainer1',
  name: 'Trainer-1',
  email: 'trainer1@example.com',
  password: 'trainer1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

u = Ugrp::User.new(
  username: 'trainer2',
  name: 'Trainer-2',
  email: 'trainer2@example.com',
  password: 'trainer2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

# Attendees
u = Ugrp::User.new(
  username: 'attendee1',
  name: 'Attendee-1',
  email: 'attendee1@example.com',
  password: 'attendee1',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee2',
  name: 'Attendee-2',
  email: 'attendee2@example.com',
  password: 'attendee2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee3',
  name: 'Attendee-3',
  email: 'attendee3@example.com',
  password: 'attendee3',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee4',
  name: 'Attendee-4',
  email: 'attendee4@example.com',
  password: 'attendee4',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

# Generate unconfirmed user
#  - this user is to speed up integration test cycles (see: features/support/hooks )

u = Ugrp::User.new(
  username: 'unconfirmed_user',
  name: 'Unconfirmed user',
  email: 'unconfirmed_user@htcl.eu',
  password: 'unconfirmed_user',
  confirmed_at: Time.now
)
u.save!

# Generate cucumber_user
#  - this user is to speed up integration test cycles (see: features/support/hooks )

u = Ugrp::User.new(
  username: 'cucumber_user',
  name: 'cucumber_user',
  email: 'cucumber_user@example.com',
  password: 'cucumber_user',
  confirmed_at: Time.now
)
u.save!

==> ugrp-0.2.2.gem: spec/dummy/db/seed/once/development/0520_ugrp_users.rb <==
# frozen_string_literal: true

# The actual administrator
u = Ugrp::User.new(
  username: 'administrator',
  name: 'Administrator',
  email: 'administrator@example.com',
  password: 'administrator',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
u.roles << Ugrp::Role.find_by_name('r_super_user')
u.save!

# Everard
u = Ugrp::User.new(
  username: 'everard',
  name: 'Everard Brown',
  email: 'everard.brown@htcl.eu',
  password: '3v3rard@dev',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
u.roles << Ugrp::Role.find_by(name: 'r_developer')
# u.roles << Ugrp::Role.find_by(name: 'trainer', domain: Ugrp::Domain.default_domain)
u.save!

# file = File.new(File.expand_path('images/em.png', __FILE__), binmode: true, encoding: "ASCII-8BIT")
# data = file.read
# photo = AssetManagement::AssetData.create(
#   filename: File.basename(file.path),
#   data: data,
#   size: data.size,
#   mime_type: 'image/jpeg',
#   folder: AssetManagement::VirtualFolder.find_by(name: 'images')
# )

#
# Generate development/test user accounts ------------------------------------------
#

# The domain_administrator
u = Ugrp::User.new(
  username: 'domain_administrator',
  name: 'Domain Admin',
  email: 'domain_administrator@example.com',
  password: 'domain_administrator',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('domain_administrator')
u.save!

# The manager
u = Ugrp::User.new(
  username: 'manager',
  name: 'Manager',
  email: 'manager@example.com',
  password: 'manager',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

# The staff
u = Ugrp::User.new(
  username: 'staff',
  name: 'Staff',
  email: 'staff@example.com',
  password: 'staff',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

# restricted staff member
u = Ugrp::User.new(
  username: 'restricted_staff',
  name: 'Restricted staff',
  email: 'restricted_staff@example.com',
  password: 'restricted_staff',
  confirmed_at: Time.now
)
u.save!

# The trainer
u = Ugrp::User.new(
  username: 'trainer',
  name: 'Trainer',
  email: 'trainer@example.com',
  password: 'trainer',
  confirmed_at: Time.now
)
# u.domains << Ugrp::Domain.find_by_url('planit.co.uk')
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

# The attendee
u = Ugrp::User.new(
  username: 'attendee',
  name: 'Attendee',
  email: 'attendee@example.com',
  password: 'attendee',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

#
# Generate some other arbitrary users -----------------------------------------
#

# Managers
u = Ugrp::User.new(
  username: 'manager1',
  name: 'Manager-1',
  email: 'manager1@example.com',
  password: 'manager1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

u = Ugrp::User.new(
  username: 'manager2',
  name: 'Manager-2',
  email: 'manager2@example.com',
  password: 'manager2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('manager')
u.save!

# Staff
u = Ugrp::User.new(
  username: 'staff1',
  name: 'Staff-1',
  email: 'staff1@example.com',
  password: 'staff1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

u = Ugrp::User.new(
  username: 'staff2',
  name: 'Staff-2',
  email: 'staff2@example.com',
  password: 'staff2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('staff')
u.save!

# Trainers
u = Ugrp::User.new(
  username: 'trainer1',
  name: 'Trainer-1',
  email: 'trainer1@example.com',
  password: 'trainer1',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

u = Ugrp::User.new(
  username: 'trainer2',
  name: 'Trainer-2',
  email: 'trainer2@example.com',
  password: 'trainer2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('trainer')
u.save!

# Attendees
u = Ugrp::User.new(
  username: 'attendee1',
  name: 'Attendee-1',
  email: 'attendee1@example.com',
  password: 'attendee1',
  confirmed_at: Time.now
)
u.domains << Ugrp::Domain.default_domain
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee2',
  name: 'Attendee-2',
  email: 'attendee2@example.com',
  password: 'attendee2',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee3',
  name: 'Attendee-3',
  email: 'attendee3@example.com',
  password: 'attendee3',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

u = Ugrp::User.new(
  username: 'attendee4',
  name: 'Attendee-4',
  email: 'attendee4@example.com',
  password: 'attendee4',
  confirmed_at: Time.now
)
# u.roles << Ugrp::Role.find_by_name('attendee')
u.save!

# Generate unconfirmed user
#  - this user is to speed up integration test cycles (see: features/support/hooks )

u = Ugrp::User.new(
  username: 'unconfirmed_user',
  name: 'Unconfirmed user',
  email: 'unconfirmed_user@htcl.eu',
  password: 'unconfirmed_user',
  confirmed_at: Time.now
)
u.save!

# Generate cucumber_user
#  - this user is to speed up integration test cycles (see: features/support/hooks )

u = Ugrp::User.new(
  username: 'cucumber_user',
  name: 'cucumber_user',
  email: 'cucumber_user@example.com',
  password: 'cucumber_user',
  confirmed_at: Time.now
)
u.save!
